| result_summary | R Documentation |
Produces win/loss/draw counts for a specified player
result_summary(games, player)
games |
Tibble returned by |
player |
Username (required for accurate W/L/D). |
A tibble with one row containing the player name plus totals for games, wins, losses, and draws.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.