user: Get a user's public profile

View source: R/user.R

userR Documentation

Get a user's public profile

Description

Retrieves a public user profile from the Lichess API.

Usage

user(cl, username, tz = "UTC")

Arguments

cl

A horsey_client.

username

Lichess username.

tz

Time zone for the returned datetime fields. Defaults to "UTC".

Value

A tibble with selected fields, plus a raw list-column.


horsey documentation built on Jan. 22, 2026, 5:07 p.m.