| user_activity | R Documentation |
Retrieves the activity feed for a user. This wrapper intentionally returns a minimal summary and includes the raw activity objects in a list-column.
user_activity(cl, username)
cl |
A |
username |
Lichess username. |
A tibble with one row per activity entry and a raw column.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.