Learn R Programming

horsey (version 1.0.1)

opening_summary: Summarize openings from exported games

Description

Counts openings from export_games() output. To include opening information, opening = TRUE in export_games().

Usage

opening_summary(games, top_n = 20)

Value

A tibble of the most common openings with columns for the ECO code, opening name, and count of games.

Arguments

games

Tibble returned by export_games().

top_n

Number of top openings to return.

Details

Two columns are produced by export_games() when opening = TRUE:

opening_name

An opening name provided by Lichess (for example, "Sicilian Defense" or "Queen's Gambit Declined").

opening_eco

The ECO code associated with the opening (for example, "B20" or "D30"). ECO (Encyclopaedia of Chess Openings) codes are a standardized classification system for chess openings.