Counts openings from export_games() output.
To include opening information, opening = TRUE in
export_games().
opening_summary(games, top_n = 20)A tibble of the most common openings with columns for the ECO code, opening name, and count of games.
Tibble returned by export_games().
Number of top openings to return.
Two columns are produced by export_games() when
opening = TRUE:
An opening name provided by Lichess (for example, "Sicilian Defense" or "Queen's Gambit Declined").
The ECO code associated with the opening (for example, "B20" or "D30"). ECO (Encyclopaedia of Chess Openings) codes are a standardized classification system for chess openings.