Learn R Programming

horsey (version 1.0.1)

result_summary: Summarize results (W/L/D) for a player

Description

Produces win/loss/draw counts for a specified player

Usage

result_summary(games, player)

Value

A tibble with one row containing the player name plus totals for games, wins, losses, and draws.

Arguments

games

Tibble returned by export_games().

player

Username (required for accurate W/L/D).