| user | R Documentation |
Retrieves a public user profile from the Lichess API.
user(cl, username, tz = "UTC")
cl |
A |
username |
Lichess username. |
tz |
Time zone for the returned datetime fields. Defaults to |
A tibble with selected fields, plus a raw list-column.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.