user_activity: Get a user's activity feed
Description
Retrieves the activity feed for a user. This wrapper intentionally returns
a minimal summary and includes the raw activity objects in a list-column.
Usage
user_activity(cl, username)
Value
A tibble with one row per activity entry and a raw column.
Arguments
- cl
A horsey_client.
- username
Lichess username.